pyramid_localize
================


.. image:: https://img.shields.io/pypi/v/pyramid_localize.svg
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/pyramid_localize/badge/?version=v1.0.7
    :target: http://pyramid_localize.readthedocs.io/en/v1.0.7/
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/wheel/pyramid_localize.svg
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Wheel Status

.. image:: https://img.shields.io/pypi/pyversions/pyramid_localize.svg
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/pyramid_localize.svg
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: License

**pyramid_localize** is a pyramid extension providing ready-to-use, translation
functionality for your pyramid based projects. All you need is to add Babel,
and add some configuration. localize provides also a web interface that allows
you to reload translations live, without reloading application.


Package resources
-----------------

* Bug tracker: https://github.com/fizyk/pyramid_localize/issues
* Documentation: http://pyramid-localize.readthedocs.org/
* PyPI: https://pypi.python.org/pypi/pyramid_localize


Instalation:
============

``pip install pyramid_localize``

or add **pyramid_localize** to your project requirements.

Release
=======

Install pipenv first, Then run:

.. code-block::

    pipenv run tbump [NEW_VERSION]
